==> qtjambi-help-5.15-sources.jar: io/qt/help/QCompressedHelpInfo.java <==
package io.qt.help;


/**
 * <p>Access to the details about a compressed help file</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html">QCompressedHelpInfo</a></p>
 */
public final class QCompressedHelpInfo extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#QCompressedHelpInfo">QCompressedHelpInfo::QCompressedHelpInfo()</a></p>
     */
    public QCompressedHelpInfo(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QCompressedHelpInfo instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#QCompressedHelpInfo-1">QCompressedHelpInfo::QCompressedHelpInfo(QCompressedHelpInfo)</a></p>
     */
    public QCompressedHelpInfo(io.qt.help.QCompressedHelpInfo other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QCompressedHelpInfo instance, io.qt.help.QCompressedHelpInfo other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#component">QCompressedHelpInfo::component()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String component(){
        return component_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String component_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#isNull">QCompressedHelpInfo::isNull()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#namespaceName">QCompressedHelpInfo::namespaceName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String namespaceName(){
        return namespaceName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String namespaceName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#swap">QCompressedHelpInfo::swap(QCompressedHelpInfo&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void swap(io.qt.help.QCompressedHelpInfo other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QCompressedHelpInfo(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QCompressedHelpInfo(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#version">QCompressedHelpInfo::version()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVersionNumber version(){
        return version_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVersionNumber version_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qcompressedhelpinfo.html#fromCompressedHelpFile">QCompressedHelpInfo::fromCompressedHelpFile(QString)</a></p>
     */
    public native static io.qt.help.QCompressedHelpInfo fromCompressedHelpFile(java.lang.String documentationFileName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCompressedHelpInfo(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QCompressedHelpInfo clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QCompressedHelpInfo clone_native(long __this_nativeId);
}

==> qtjambi-help-6.2.5-sources.jar: io/qt/help/QCompressedHelpInfo.java <==
package io.qt.help;


/**
 * <p>Access to the details about a compressed help file</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html">QCompressedHelpInfo</a></p>
 */
public final class QCompressedHelpInfo extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#QCompressedHelpInfo">QCompressedHelpInfo::QCompressedHelpInfo()</a></p>
     */
    public QCompressedHelpInfo(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QCompressedHelpInfo instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#QCompressedHelpInfo-1">QCompressedHelpInfo::QCompressedHelpInfo(QCompressedHelpInfo)</a></p>
     */
    public QCompressedHelpInfo(io.qt.help.QCompressedHelpInfo other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QCompressedHelpInfo instance, io.qt.help.QCompressedHelpInfo other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#component">QCompressedHelpInfo::component()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String component(){
        return component_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String component_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#isNull">QCompressedHelpInfo::isNull()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#namespaceName">QCompressedHelpInfo::namespaceName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String namespaceName(){
        return namespaceName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String namespaceName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#swap">QCompressedHelpInfo::swap(QCompressedHelpInfo&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void swap(io.qt.help.QCompressedHelpInfo other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QCompressedHelpInfo(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QCompressedHelpInfo(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#version">QCompressedHelpInfo::version()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVersionNumber version(){
        return version_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVersionNumber version_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qcompressedhelpinfo.html#fromCompressedHelpFile">QCompressedHelpInfo::fromCompressedHelpFile(QString)</a></p>
     */
    public native static io.qt.help.QCompressedHelpInfo fromCompressedHelpFile(java.lang.String documentationFileName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCompressedHelpInfo(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QCompressedHelpInfo clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QCompressedHelpInfo clone_native(long __this_nativeId);
}
